Use Case:  Browse the site homepage
===================================

Actor
-----

Site Visitor

Assumptions
-----------

Site Visitor has already navigated to a page within the CMF site [#]_.

Procedure
---------

1. Selecting the 'home' link or the site logo from the top navigation bar.

2. Browse the content published there (e.g. 10 most recent News
   Announcements, etc.)

.. rubric:: Notes

.. [#]
   Site Visitors may get to the site initially through several mechanisms:

   * Links on another site, such as a search engine
   * Mailed URLs
   * Typing the URL directly
